package jp.co.argo21.nautica.workflow.soap;

import javax.annotation.Resource;
import javax.jws.WebService;
import javax.xml.ws.WebServiceContext;

import org.apache.log4j.Logger;

import jp.co.argo21.nautica.workflow.client.WorkflowServiceAccessor;
import jp.co.argo21.nautica.workflow.soap.message.Activity;
import jp.co.argo21.nautica.workflow.soap.message.ActivityState;
import jp.co.argo21.nautica.workflow.soap.message.Attribute;
import jp.co.argo21.nautica.workflow.soap.message.Filter;
import jp.co.argo21.nautica.workflow.soap.message.Process;
import jp.co.argo21.nautica.workflow.soap.message.ProcessState;
import jp.co.argo21.nautica.workflow.util.StringManager;
import jp.co.argo21.nautica.workflow.wfmc.AttributeAssignmentFailedException;
import jp.co.argo21.nautica.workflow.wfmc.InvalidActivityInstanceException;
import jp.co.argo21.nautica.workflow.wfmc.InvalidAttributeException;
import jp.co.argo21.nautica.workflow.wfmc.InvalidFilterException;
import jp.co.argo21.nautica.workflow.wfmc.InvalidProcessDefinitionException;
import jp.co.argo21.nautica.workflow.wfmc.InvalidProcessInstanceException;
import jp.co.argo21.nautica.workflow.wfmc.InvalidSessionException;
import jp.co.argo21.nautica.workflow.wfmc.InvalidStateException;
import jp.co.argo21.nautica.workflow.wfmc.TransitionNotAllowedException;

class SysoutLogger extends Logger {
	public SysoutLogger(String name) {
		super(name);
	}

	@Override
	public void error(Object message) {
		System.out.println("**" + message);
	}

	@Override
	public void info(Object message) {
		System.out.println("**" + message);
	}
}

@WebService(serviceName = "WorkflowEngineHandler",
        portName="WorkflowEngineHandlerPort",
        endpointInterface = "jp.co.argo21.nautica.workflow.soap.WorkflowEngineHandler",
        targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap",
        wsdlLocation = "WEB-INF/wsdl/WorkflowEngineHandler.wsdl")
public class WorkflowEngineHandlerSoapBindingImpl implements
		WorkflowEngineHandler {

	/** ログ出力用オブジェクト */
	private static Logger log = new SysoutLogger(
			WorkflowEngineHandlerSoapBindingImpl.class.getName());
	
	@Resource
    private WebServiceContext context;
	
	/**
	 * アクティビティインスタンス属性の割り当てを行う。
	 *
	 * @param session セッションID
	 * @param pid プロセスインスタンスID
	 * @param aid アクティビティインスタンスID
	 * @param attr 属性
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidProcessInstanceException プロセスインスタンスIDが有効でない場合
	 * @throws InvalidActivityInstanceException アクティビティインスタンスIDが有効でない場合
	 * @throws InvalidAttributeException 属性が有効でない場合
	 * @throws AttributeAssignmentFailedException 属性の割り当てに失敗した場合
	 */
	@Override
	public void assignActivityAttribute(String session, String pid, String aid,
			Attribute attr) throws InvalidSessionException, InvalidProcessInstanceException, InvalidActivityInstanceException, InvalidAttributeException, AttributeAssignmentFailedException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", ProcessInstanceID=" + pid 
			+ ", ActivityInstanceID=" + aid 
			+ ", AttributeName=" + attr.getName() + ")";
		log.info(I4001);
		
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			weh.assignActivityAttribute(
					session, 
					pid, 
					aid, 
					attr.toWfmcAttribute());
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidProcessInstanceException e) {
			String errMsg = StringManager.get("E0226");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidActivityInstanceException e) {
			String errMsg = StringManager.get("E0203");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidAttributeException e) {
			String errMsg = StringManager.get("E0233");
			log.error(errMsg, e);
			throw e;
		} catch (AttributeAssignmentFailedException e) {
			String errMsg = StringManager.get("E0232");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002");
	   log.info(I4002);
		
	}

	/**
	 * プロセスインスタンス属性の割り当てを行う。
	 *
	 * @param session セッションID
	 * @param pid プロセスインスタンスID
	 * @param attr 属性
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidProcessInstanceException プロセスインスタンスIDが有効でない場合
	 * @throws InvalidAttributeException 属性が有効でない場合
	 * @throws AttributeAssignmentFailedException 属性の割り当てに失敗した場合
	 */
	@Override
	public void assignProcessAttribute(String session, String pid,
			Attribute attr) throws InvalidSessionException, InvalidProcessInstanceException, InvalidAttributeException, AttributeAssignmentFailedException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", ProcessInstanceID=" + pid 
			+ ", Attribute=" + attr + ")";
		log.info(I4001);
		
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			weh.assignProcessAttribute(session, pid, attr.toWfmcAttribute());
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidProcessInstanceException e) {
			String errMsg = StringManager.get("E0226");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidAttributeException e) {
			String errMsg = StringManager.get("E0233");
			log.error(errMsg, e);
			throw e;
		} catch (AttributeAssignmentFailedException e) {
			String errMsg = StringManager.get("E0232");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002");
	   log.info(I4002);
		
	}

	/**
	 * アクティビティインスタンス状態の変更を行う。
	 *
	 * @param session セッションID
	 * @param pid プロセスインスタンスID
	 * @param aid アクティビティインスタンスID
	 * @param state アクティビティインスタンス状態
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidProcessInstanceException プロセスインスタンスIDが有効でない場合
	 * @throws InvalidActivityInstanceException アクティビティインスタンスIDが有効でない場合
	 * @throws InvalidStateException 指定された状態が有効でない場合
	 * @throws TransitionNotAllowedException 状態の変更が許可されていない場合
	 */
	@Override
	public void changeActivityState(String session, String pid,
			String aid, ActivityState state) throws InvalidSessionException, InvalidProcessInstanceException, InvalidActivityInstanceException, InvalidStateException, TransitionNotAllowedException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", ProcessInstanceID=" + pid 
			+ ", ActivityInstanceID=" + aid 
			+ ", ActivityInstanceState=" + state + ")";
		log.info(I4001);
		
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			weh.changeActivityState(
					session, 
					pid, 
					aid, 
					state.toWfmcActivityState());
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidProcessInstanceException e) {
			String errMsg = StringManager.get("E0226");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidActivityInstanceException e) {
			String errMsg = StringManager.get("E0203");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidStateException e) {
			String errMsg = StringManager.get("E0234");
			log.error(errMsg, e);
			throw e;
		} catch (TransitionNotAllowedException e) {
			String errMsg = StringManager.get("E0050");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002");
	   log.info(I4002);
		
	}

	/**
	 * プロセスインスタンス状態の変更を行う。
	 *
	 * @param session セッションID
	 * @param pid プロセスインスタンスID
	 * @param state プロセスインスタンス状態
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidProcessInstanceException プロセスインスタンスIDが有効でない場合
	 * @throws InvalidStateException 指定された状態が有効でない場合
	 * @throws TransitionNotAllowedException 状態の変更が許可されていない場合
	 */
	@Override
	public void changeProcessState(String session, String pid,
			ProcessState state) throws InvalidSessionException, InvalidProcessInstanceException, InvalidStateException, TransitionNotAllowedException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", ProcessInstanceID=" + pid 
			+ ", ProcessInstanceState=" + state + ")";
		log.info(I4001);
		
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			weh.changeProcessState(
					session, 
					pid, 
					state.toWfmcProcessState());
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidProcessInstanceException e) {
			String errMsg = StringManager.get("E0226");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidStateException e) {
			String errMsg = StringManager.get("E0234");
			log.error(errMsg, e);
			throw e;
		} catch (TransitionNotAllowedException e) {
			String errMsg = StringManager.get("E0050");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002");
	   log.info(I4002);
		
	}

	/**
	 * プロセスインスタンスの生成を行う。
	 *
	 * @param session セッションID
	 * @param pdid プロセス定義ID
	 * @param name プロセスインスタンス名称
	 * @return プロセスインスタンスID
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidProcessDefinitionException 指定されたプロセス定義IDが有効でない場合
	 */
	@Override
	public String createProcess(String session, String pdid, String name) throws InvalidSessionException, InvalidProcessDefinitionException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", ProcessDefinitionID=" + pdid 
			+ ", ProcessInstanceName=" + name + ")";
		log.info(I4001);
		
		String pid = null;
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			pid = weh.createProcess(session, pdid, name);
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidProcessDefinitionException e) {
			String errMsg = StringManager.get("E0094");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002")
			+ "(ProcessInstanceID=" + pid + ")";
   	log.info(I4002);
		return pid;
		
	}

	/**
	 * アクティビティインスタンス一覧の取得を行う。
	 * 利用可能なフィルターはNameFilterのみとする。
	 *
	 * @param session セッションID
	 * @param filter 検索用フィルター
	 * @return アクティビティインスタンス一覧
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidFilterException 指定されたフィルターが有効でない場合
	 */
	@Override
	public Activity[] getActivities(String session, Filter[] filter) throws InvalidSessionException, InvalidFilterException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", Filter=" + filter + ")";
		log.info(I4001);
		
		Activity[] as = null;
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			as = SoapMessageConverter.convertToSoapMessage(
					weh.getActivities(
							session, 
							SoapMessageConverter.convertToGroupFilter(filter)));
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidFilterException e) {
			String errMsg = StringManager.get("E0004");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002") 
			+ "(Activities=" + as + ")";
		log.info(I4002);
		return as;
		
	}

	/**
	 * アクティビティインスタンス一覧の取得を行う。
	 * 利用可能なフィルターはNameFilterのみとする。
	 * WfMC仕様ではpidはないが、これは誤りであろうと判断し、
	 * pidを引数に追加した。
	 *
	 * @param session セッションID
	 * @param pid プロセスインスタンスID
	 * @param filter 検索用フィルター
	 * @return アクティビティインスタンス一覧
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidFilterException 指定されたフィルターが有効でない場合
	 */
	@Override
	public Activity[] getActivities(String session, String pid, Filter[] filter) throws InvalidSessionException, InvalidFilterException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session
			+ ", ProcessInstanceID=" + pid
			+ ", Filter=" + filter + ")";
		log.info(I4001);
		
		Activity[] as = null;
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			as = SoapMessageConverter.convertToSoapMessage(
					weh.getActivities(
							session, 
							pid, 
							SoapMessageConverter.convertToGroupFilter(filter)));
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidFilterException e) {
			String errMsg = StringManager.get("E0004");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002") 
			+ "(Activities=" + as + ")";
		log.info(I4002);
		return as;
		
	}

	/**
	 * アクティビティインスタンスの取得を行う。
	 *
	 * @param session セッションID
	 * @param pid プロセスインスタンスID
	 * @param aid アクティビティインスタンスID
	 * @return アクティビティインスタンス
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidProcessInstanceException プロセスインスタンスIDが有効でない場合
	 * @throws InvalidActivityInstanceException アクティビティインスタンスIDが有効でない場合
	 */
	@Override
	public Activity getActivity(String session, String pid, String aid) throws InvalidSessionException, InvalidProcessInstanceException, InvalidActivityInstanceException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session
			+ ", ProcessInstanceID=" + pid
			+ ", ActivityInstanceID=" + aid + ")";
		log.info(I4001);
		
		Activity a = null;
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			a = new Activity(
					weh.getActivity(session, pid, aid));
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidProcessInstanceException e) {
			String errMsg = StringManager.get("E0226");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidActivityInstanceException e) {
			String errMsg = StringManager.get("E0203");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002") 
			+ "(ActivityInstance=" + a + ")";
		log.info(I4002);
		return a;
		
	}

	/**
	 * アクティビティインスタンス属性の属性値の取得を行う。
	 *
	 * @param session セッションID
	 * @param pid プロセスインスタンスID
	 * @param aid アクティビティインスタンスID
	 * @param name 属性名
	 * @return 属性
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidAttributeException 属性が有効でない場合
	 */
	@Override
	public Attribute getActivityAttributeValue(String session, String pid,
			String aid, String name) throws InvalidSessionException, InvalidAttributeException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", ProcessInstanceID=" + pid 
			+ ", ActivityInstanceID=" + aid 
			+ ", AttributeName=" + name + ")";
		log.info(I4001);
		
		Attribute attr = null;
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			attr = new Attribute(
					weh.getActivityAttributeValue(session, pid, aid, name));
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidAttributeException e) {
			String errMsg = StringManager.get("E0233");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002")
			+ "(Attribute=" + attr + ")";
   	log.info(I4002);
		return attr;
	}

	/**
	 * アクティビティインスタンス属性一覧の取得を行う。
	 * 利用可能なフィルターはAttributeFilterのみとする。
	 *
	 * @param session セッションID
	 * @param pid プロセスインスタンスID
	 * @param aid アクティビティインスタンスID
	 * @param filter 検索用フィルター
	 * @return アクティビティインスタンス属性一覧
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidProcessInstanceException プロセスインスタンスIDが有効でない場合
	 * @throws InvalidActivityInstanceException アクティビティインスタンスIDが有効でない場合
	 * @throws InvalidFilterException 指定されたフィルターが有効でない場合
	 */
	@Override
	public Attribute[] getActivityAttributes(String session, String pid,
			String aid, Filter[] filter) throws InvalidSessionException, InvalidProcessInstanceException, InvalidActivityInstanceException, InvalidFilterException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", ProcessInstanceID=" + pid 
			+ ", ActivityInstanceID=" + aid 
			+ ", Filter=" + filter + ")";
		log.info(I4001);
		
		Attribute[] attrs = null;
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			attrs = SoapMessageConverter.convertToSoapMessage(
					weh.getActivityAttributes(
							session, 
							pid, 
							aid, 
							SoapMessageConverter.convertToGroupFilter(filter)));
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidProcessInstanceException e) {
			String errMsg = StringManager.get("E0226");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidActivityInstanceException e) {
			String errMsg = StringManager.get("E0203");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidFilterException e) {
			String errMsg = StringManager.get("E0004");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002")
			+ "(ActivityInstanceAttributes=" + attrs + ")";
   	log.info(I4002);
		return attrs;
	}

	/**
	 * 指定されたアクティビティインスタンスが利用可能な状態一覧の取得を行う。
	 * 利用可能なフィルターはStateFilterのみとする。
	 *
	 * @param session セッションID
	 * @param pid プロセスインスタンスID
	 * @param aid アクティビティインスタンスID
	 * @param filter 検索用フィルター
	 * @return アクティビティインスタンス状態一覧
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidProcessInstanceException プロセスインスタンスIDが有効でない場合
	 * @throws InvalidActivityInstanceException アクティビティインスタンスIDが有効でない場合
	 * @throws InvalidFilterException 指定されたフィルターが有効でない場合
	 */
	@Override
	public ActivityState[] getActivityStates(String session, String pid,
			String aid, Filter[] filter) throws InvalidSessionException, InvalidProcessInstanceException, InvalidActivityInstanceException, InvalidFilterException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", ProcessInstanceID=" + pid 
			+ ", ActivityInstanceID=" + aid 
			+ ", Filter=" + filter + ")";
		log.info(I4001);
		
		ActivityState[] ass = null;
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			ass = SoapMessageConverter.convertToSoapMessage(
					weh.getActivityStates(
							session, 
							pid, 
							aid, 
							SoapMessageConverter.convertToStateFilter(filter)));
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidProcessInstanceException e) {
			String errMsg = StringManager.get("E0226");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidActivityInstanceException e) {
			String errMsg = StringManager.get("E0203");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidFilterException e) {
			String errMsg = StringManager.get("E0004");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002") 
			+ "(ActivityInstanceStates=" + ass + ")";
   	log.info(I4002);
		return ass;
	}

	/**
	 * プロセスインスタンスの取得を行う。
	 *
	 * @param session セッションID
	 * @param pid プロセスインスタンスID
	 * @return プロセスインスタンス
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidProcessInstanceException プロセスインスタンスIDが有効でない場合
	 */
	@Override
	public Process getProcess(String session, String pid) throws InvalidSessionException, InvalidProcessInstanceException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", ProcessInstanceID=" + pid + ")";
		log.info(I4001);
		
		Process p = null;
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			p = new Process(
					weh.getProcess(session, pid));
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidProcessInstanceException e) {
			String errMsg = StringManager.get("E0226");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002") 
			+ "(ProcessInstance=" + p + ")";
		log.info(I4002);
		return p;
		
	}

	/**
	 * プロセスインスタンス属性の属性値の取得を行う。
	 *
	 * @param session セッションID
	 * @param pid プロセスインスタンスID
	 * @param name 属性名
	 * @return 属性
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidAttributeException 属性が有効でない場合
	 */
	@Override
	public Attribute getProcessAttributeValue(String session, String pid,
			String name) throws InvalidSessionException, InvalidAttributeException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", ProcessInstanceID=" + pid 
			+ ", AttributeName=" + name + ")";
		log.info(I4001);
		
		Attribute attr = null;
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			attr = new Attribute(
					weh.getProcessAttributeValue(session, pid, name));
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidAttributeException e) {
			String errMsg = StringManager.get("E0233");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002") 
			+ "(Attribute=" + attr + ")";
   	log.info(I4002);
		return attr;
		
	}

	/**
	 * プロセスインスタンス属性一覧の取得を行う。
	 * 利用可能なフィルターはAttributeFilterのみとする。
	 *
	 * @param session セッションID
	 * @param pid プロセスインスタンスID
	 * @param filter 検索用フィルター
	 * @return 属性一覧
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidProcessInstanceException プロセスインスタンスIDが有効でない場合
	 * @throws InvalidFilterException 指定されたフィルターが有効でない場合
	 */
	@Override
	public Attribute[] getProcessAttributes(String session, String pid,
			Filter[] filter) throws InvalidSessionException, InvalidProcessInstanceException, InvalidFilterException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", ProcessInstanceID=" + pid 
			+ ", Filter=" + filter + ")";
		log.info(I4001);
		
		Attribute[] attrs = null;
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			attrs = SoapMessageConverter.convertToSoapMessage(
					weh.getProcessAttributes(
							session, 
							pid, 
							SoapMessageConverter.convertToGroupFilter(filter)));
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidProcessInstanceException e) {
			String errMsg = StringManager.get("E0226");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidFilterException e) {
			String errMsg = StringManager.get("E0004");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002") 
			+ "(Attributes=" + attrs + ")";
   	log.info(I4002);
		return attrs;
		
	}

	/**
	 * 指定されたプロセスインスタンスが利用可能な状態一覧の取得を行う。
	 * 利用可能なフィルターはStateFilterのみとする。
	 *
	 * @param session セッションID
	 * @param pid プロセスインスタンスID
	 * @param filter 検索用フィルター
	 * @return プロセスインスタンス状態一覧
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidProcessInstanceException プロセスインスタンスIDが有効でない場合
	 * @throws InvalidFilterException 指定されたフィルターが有効でない場合
	 */
	@Override
	public ProcessState[] getProcessStates(String session, String pid,
			Filter[] filter) throws InvalidSessionException, InvalidProcessInstanceException, InvalidFilterException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", ProcessInstanceID=" + pid 
			+ ", Filter=" + filter + ")";
		log.info(I4001);
		
		ProcessState[] pss = null;
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			pss = SoapMessageConverter.convertToSoapMessage(
					weh.getProcessStates(
							session, 
							pid, 
							SoapMessageConverter.convertToStateFilter(filter)));
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidProcessInstanceException e) {
			String errMsg = StringManager.get("E0226");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidFilterException e) {
			String errMsg = StringManager.get("E0004");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002") 
			+ "(ProcessInstances=" + pss + ")";
   	log.info(I4002);
		return pss;
		
	}

	/**
	 * プロセスインスタンス一覧の取得を行う。
	 * 利用可能なフィルターはNameFilterのみとする。
	 *
	 * @param session セッションID
	 * @param filter 検索用フィルター
	 * @return プロセスの一覧
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidFilterException 指定されたフィルターが有効でない場合
	 */
	@Override
	public Process[] getProcesses(String session, Filter[] filter) throws InvalidSessionException, InvalidFilterException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", Filter=" + filter + ")";
		log.info(I4001);
		
		Process[] ps = null;
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			ps = SoapMessageConverter.convertToSoapMessage(
					weh.getProcesses(
							session, 
							SoapMessageConverter.convertToGroupFilter(filter)));
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidFilterException e) {
			String errMsg = StringManager.get("E0004");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002") 
			+ "(Processes=" + ps + ")";
   	log.info(I4002);
		return ps;
		
	}

	/**
	 * プロセスインスタンスの開始を行う。
	 * 開始した場合に、プロセスインスタンスIDを更新するような
	 * 実装も可能である。
	 *
	 * @param session セッションID
	 * @param pid プロセスインスタンスID
	 * @return 更新されたプロセスインスタンスID
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidProcessInstanceException プロセスインスタンスIDが有効でない場合
	 * @throws InvalidAttributeException 属性が有効でない場合
	 */
	@Override
	public String startProcess(String session, String pid) throws InvalidSessionException, InvalidProcessInstanceException, InvalidAttributeException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", ProcessInstanceID=" + pid + ")";
		log.info(I4001);
		
		String startedPid = null;
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			startedPid = weh.startProcess(session, pid);
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidProcessInstanceException e) {
			String errMsg = StringManager.get("E0226");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidAttributeException e) {
			String errMsg = StringManager.get("E0233");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002")
		+ "(ProcessInstanceID=" + startedPid + ")";
   	log.info(I4002);
		return startedPid;
	}

	/**
	 * プロセスインスタンスの停止を行う。
	 *
	 * @param session セッションID
	 * @param pid プロセスインスタンスID
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 * @throws InvalidProcessInstanceException プロセスインスタンスIDが有効でない場合
	 */
	@Override
	public void terminateProcess(String session, String pid) throws InvalidSessionException, InvalidProcessInstanceException {
		
		String I4001 = StringManager.get("I4001")
			+ "(SessionID=" + session 
			+ ", ProcessInstanceID=" + pid + ")";
		log.info(I4001);
		
		try {
			WorkflowServiceAccessor accessor = SingletonServices.getInstance().getAccessor(session);
			jp.co.argo21.nautica.workflow.wfmc.WorkflowEngineHandler weh = accessor.getWorkflowEngineHandler();
			weh.terminateProcess(session, pid);
		} catch (InvalidSessionException e) {
			String errMsg = StringManager.get("E1015");
			log.error(errMsg, e);
			throw e;
		} catch (InvalidProcessInstanceException e) {
			String errMsg = StringManager.get("E0226");
			log.error(errMsg, e);
			throw e;
		}
		
		String I4002 = StringManager.get("I4002");
		log.info(I4002);
		
	}

	public WebServiceContext getContext() {
		return context;
	}
	
}