package jp.co.argo21.nautica.workflow.soap;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebResult;
import javax.jws.WebService;
import javax.xml.ws.RequestWrapper;
import javax.xml.ws.ResponseWrapper;

import jp.co.argo21.nautica.workflow.wfmc.ConnectionFailedException;
import jp.co.argo21.nautica.workflow.wfmc.InvalidSessionException;

@WebService(name="WorkflowServiceConnector",
        targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
public interface WorkflowServiceConnector {

	/**
	 * ワークフローエンジンへの接続認証を行い、
	 * セッションIDを取得する。
	 *
	 * @param user ユーザID
	 * @param pass パスワード
	 * @return セッションID
	 * @throws ConnectionFailedException 接続認証に失敗した場合
	 */
	@WebMethod(operationName = "connect")
	@WebResult(name = "return", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message")
	@RequestWrapper(localName = "connect", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.Connect")
	@ResponseWrapper(localName = "connectResponse", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.ConnectResponse")   
	public String connect(@WebParam(name = "user") String user, @WebParam(name = "passwd") String passwd) throws ConnectionFailedException;
	
	/**
	 * ワークフローエンジンとの切断を行う。
	 *
	 * @param session セッションID
	 * @throws InvalidSessionException 指定されたセッションが無効の場合
	 */
	@WebMethod(operationName = "disconnect")
	@RequestWrapper(localName = "disconnect", targetNamespace = "http://www.argo21.co.jp/nautica/workflow/soap/message", className = "jp.co.argo21.nautica.workflow.soap.Disconnect")
	public void disconnect(@WebParam(name = "session") String session) throws InvalidSessionException;
	
}